/*
Copyright 2020 The Vitess Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1beta1

import (
	"context"
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"

	v1beta1 "vitess.io/vitess/go/vt/topo/k8stopo/apis/topo/v1beta1"
	scheme "vitess.io/vitess/go/vt/topo/k8stopo/client/clientset/versioned/scheme"
)

// VitessTopoNodesGetter has a method to return a VitessTopoNodeInterface.
// A group's client should implement this interface.
type VitessTopoNodesGetter interface {
	VitessTopoNodes(namespace string) VitessTopoNodeInterface
}

// VitessTopoNodeInterface has methods to work with VitessTopoNode resources.
type VitessTopoNodeInterface interface {
	Create(*v1beta1.VitessTopoNode) (*v1beta1.VitessTopoNode, error)
	Update(*v1beta1.VitessTopoNode) (*v1beta1.VitessTopoNode, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1beta1.VitessTopoNode, error)
	List(opts v1.ListOptions) (*v1beta1.VitessTopoNodeList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.VitessTopoNode, err error)
	VitessTopoNodeExpansion
}

// vitessTopoNodes implements VitessTopoNodeInterface
type vitessTopoNodes struct {
	client rest.Interface
	ns     string
}

// newVitessTopoNodes returns a VitessTopoNodes
func newVitessTopoNodes(c *TopoV1beta1Client, namespace string) *vitessTopoNodes {
	return &vitessTopoNodes{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the vitessTopoNode, and returns the corresponding vitessTopoNode object, and an error if there is any.
func (c *vitessTopoNodes) Get(name string, options v1.GetOptions) (result *v1beta1.VitessTopoNode, err error) {
	result = &v1beta1.VitessTopoNode{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("vitesstoponodes").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(context.TODO()).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of VitessTopoNodes that match those selectors.
func (c *vitessTopoNodes) List(opts v1.ListOptions) (result *v1beta1.VitessTopoNodeList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1beta1.VitessTopoNodeList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("vitesstoponodes").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(context.TODO()).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested vitessTopoNodes.
func (c *vitessTopoNodes) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("vitesstoponodes").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(context.TODO())
}

// Create takes the representation of a vitessTopoNode and creates it.  Returns the server's representation of the vitessTopoNode, and an error, if there is any.
func (c *vitessTopoNodes) Create(vitessTopoNode *v1beta1.VitessTopoNode) (result *v1beta1.VitessTopoNode, err error) {
	result = &v1beta1.VitessTopoNode{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("vitesstoponodes").
		Body(vitessTopoNode).
		Do(context.TODO()).
		Into(result)
	return
}

// Update takes the representation of a vitessTopoNode and updates it. Returns the server's representation of the vitessTopoNode, and an error, if there is any.
func (c *vitessTopoNodes) Update(vitessTopoNode *v1beta1.VitessTopoNode) (result *v1beta1.VitessTopoNode, err error) {
	result = &v1beta1.VitessTopoNode{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("vitesstoponodes").
		Name(vitessTopoNode.Name).
		Body(vitessTopoNode).
		Do(context.TODO()).
		Into(result)
	return
}

// Delete takes name of the vitessTopoNode and deletes it. Returns an error if one occurs.
func (c *vitessTopoNodes) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("vitesstoponodes").
		Name(name).
		Body(options).
		Do(context.TODO()).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *vitessTopoNodes) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("vitesstoponodes").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do(context.TODO()).
		Error()
}

// Patch applies the patch and returns the patched vitessTopoNode.
func (c *vitessTopoNodes) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.VitessTopoNode, err error) {
	result = &v1beta1.VitessTopoNode{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("vitesstoponodes").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do(context.TODO()).
		Into(result)
	return
}
